AlekSIS — Unofficial App Order (Manage orders)
==============================================

AlekSIS
-------

This is an **unofficial** application for use with the `AlekSIS`_ platform.

Features
--------

This application can be used to create order forms and manage orders e. g. for school clothes.

Licence
-------

::

  Copyright © 2020, 2021 Jonathan Weth <dev@jonathanweth.de>
  Copyright © 2021 Hangzhi Yu <yuha@katharineum.de>

  Licenced under the EUPL, version 1.2 or later

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

.. _AlekSIS: https://edugit.org/AlekSIS/AlekSIS
.. _European Union Public Licence: https://eupl.eu/
